timeintervaltools
=================

.. automodule:: abjad.tools.timeintervaltools

.. only:: html

   Abstract classes
   ----------------

   .. autosummary::

      ~abjad.tools.timeintervaltools.TimeIntervalAggregateMixin.TimeIntervalAggregateMixin.TimeIntervalAggregateMixin
      ~abjad.tools.timeintervaltools.TimeIntervalMixin.TimeIntervalMixin.TimeIntervalMixin

   Concrete classes
   ----------------

   .. autosummary::

      ~abjad.tools.timeintervaltools.TimeInterval.TimeInterval.TimeInterval
      ~abjad.tools.timeintervaltools.TimeIntervalTree.TimeIntervalTree.TimeIntervalTree
      ~abjad.tools.timeintervaltools.TimeIntervalTreeDictionary.TimeIntervalTreeDictionary.TimeIntervalTreeDictionary
      ~abjad.tools.timeintervaltools.TimeIntervalTreeNode.TimeIntervalTreeNode.TimeIntervalTreeNode

   Functions
   ---------

   .. autosummary::

      ~abjad.tools.timeintervaltools.concatenate_trees.concatenate_trees
      ~abjad.tools.timeintervaltools.make_test_intervals.make_test_intervals
      ~abjad.tools.timeintervaltools.mask_intervals_with_intervals.mask_intervals_with_intervals
      ~abjad.tools.timeintervaltools.resolve_overlaps_between_nonoverlapping_trees.resolve_overlaps_between_nonoverlapping_trees
